@@ -285,7 +285,7 @@ void CharTable::mousePressEvent(TQMouseEvent *e)
 
 void CharTable::mouseMoveEvent(TQMouseEvent *e)
 {
-    if(!(e->state() & (Qt::LeftButton | Qt::RightButton | Qt::MidButton))) return;
+    if(!(e->state() & (TQt::LeftButton | TQt::RightButton | TQt::MidButton))) return;
 
     int row = findRow(e->y());
     if (row == -1) return;
@@ -311,7 +311,7 @@ void CharTable::selectCell(int row, int col)
     repaintCell(_activeRow, _activeCol);
 
     TQClipboard *cb = TQApplication::clipboard();
-    TQObject::disconnect( cb, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clearCell()) );
+    TQObject::disconnect( cb, TQ_SIGNAL(dataChanged()), this, TQ_SLOT(clearCell()) );
     TQString text = TQString(_map[col + row * _cols]);
     bool oldMode = cb->selectionModeEnabled();
     cb->setSelectionMode( true );
@@ -319,7 +319,7 @@ void CharTable::selectCell(int row, int col)
     cb->setSelectionMode( false );
     cb->setText( text );
     cb->setSelectionMode(  oldMode );
-    TQObject::connect( cb, TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clearCell()) );
+    TQObject::connect( cb, TQ_SIGNAL(dataChanged()), this, TQ_SLOT(clearCell()) );
 }
 
 void CharTable::clearCell()
@@ -332,7 +332,7 @@ void CharTable::clearCell()
 
     repaintCell(oldRow, oldCol);
     
-    TQObject::disconnect( TQApplication::clipboard(), TQT_SIGNAL(dataChanged()), this, TQT_SLOT(clearCell()) );
+    TQObject::disconnect( TQApplication::clipboard(), TQ_SIGNAL(dataChanged()), this, TQ_SLOT(clearCell()) );
 }
 
 
