@@ -60,16 +60,16 @@ CHexEditorWidget::CHexEditorWidget( TQWidget *parent, const char *name )
   mHexView = new CHexViewWidget( this, "hexview", hexBuffer );
   if( mHexView == 0 || mHexView->widgetValid() == false ) { return; }
 
-  connect( mHexView, TQT_SIGNAL(pleaseOpenNewFile()), TQT_SLOT( newFile()) );
-  connect( mHexView, TQT_SIGNAL(pleaseOpenFile( const TQString&, bool, uint )),
-	   TQT_SLOT( open(const TQString&, bool, uint)) );
-  connect( mHexView, TQT_SIGNAL(pleaseStepFile(bool)), TQT_SLOT( stepFile(bool)) );
-  connect( kapp, TQT_SIGNAL( tdedisplayFontChanged() ), TQT_SLOT( fontChanged() ) );
-  connect( kapp, TQT_SIGNAL( tdedisplayPaletteChanged() ),TQT_SLOT( paletteChanged()) );
-  connect( mHexView, TQT_SIGNAL( layoutChanged( const SDisplayLayout & ) ),
-	   TQT_SLOT( layoutChanged( const SDisplayLayout & ) ) );
-  connect( mHexView, TQT_SIGNAL( inputModeChanged( const SDisplayInputMode & ) ),
-	   this, TQT_SLOT( inputModeChanged( const SDisplayInputMode & ) ) );
+  connect( mHexView, TQ_SIGNAL(pleaseOpenNewFile()), TQ_SLOT( newFile()) );
+  connect( mHexView, TQ_SIGNAL(pleaseOpenFile( const TQString&, bool, uint )),
+	   TQ_SLOT( open(const TQString&, bool, uint)) );
+  connect( mHexView, TQ_SIGNAL(pleaseStepFile(bool)), TQ_SLOT( stepFile(bool)) );
+  connect( kapp, TQ_SIGNAL( tdedisplayFontChanged() ), TQ_SLOT( fontChanged() ) );
+  connect( kapp, TQ_SIGNAL( tdedisplayPaletteChanged() ),TQ_SLOT( paletteChanged()) );
+  connect( mHexView, TQ_SIGNAL( layoutChanged( const SDisplayLayout & ) ),
+	   TQ_SLOT( layoutChanged( const SDisplayLayout & ) ) );
+  connect( mHexView, TQ_SIGNAL( inputModeChanged( const SDisplayInputMode & ) ),
+	   this, TQ_SLOT( inputModeChanged( const SDisplayInputMode & ) ) );
 
   mHexView->setFocus();
   setBackgroundColor( palette().active().base() );
@@ -1167,12 +1167,12 @@ void CHexEditorWidget::exportDialog( void )
   {
     mExportDialog = new CExportDialog( topLevelWidget(), 0, false );
     if( mExportDialog == 0 ) { return; }
-    connect( mExportDialog, TQT_SIGNAL( exportText(const SExportText &)),
-	     this, TQT_SLOT( exportText( const SExportText &)) );
-    connect( mExportDialog, TQT_SIGNAL( exportHtml(const SExportHtml &)),
-	     this, TQT_SLOT( exportHtml( const SExportHtml &)) );
-    connect( mExportDialog, TQT_SIGNAL( exportCArray(const SExportCArray &)),
-	     this, TQT_SLOT( exportCArray( const SExportCArray &)) );
+    connect( mExportDialog, TQ_SIGNAL( exportText(const SExportText &)),
+	     this, TQ_SLOT( exportText( const SExportText &)) );
+    connect( mExportDialog, TQ_SIGNAL( exportHtml(const SExportHtml &)),
+	     this, TQ_SLOT( exportHtml( const SExportHtml &)) );
+    connect( mExportDialog, TQ_SIGNAL( exportCArray(const SExportCArray &)),
+	     this, TQ_SLOT( exportCArray( const SExportCArray &)) );
   }
   mExportDialog->show();
 }
@@ -1449,8 +1449,8 @@ void CHexEditorWidget::gotoOffset( void )
   {
     mGotoDialog = new CGotoDialog( topLevelWidget(), 0, false );
     if( mGotoDialog == 0 ) { return; }
-    connect( mGotoDialog, TQT_SIGNAL(gotoOffset( uint, uint, bool, bool )),
-	     mHexView, TQT_SLOT(gotoOffset( uint, uint, bool, bool )) );
+    connect( mGotoDialog, TQ_SIGNAL(gotoOffset( uint, uint, bool, bool )),
+	     mHexView, TQ_SLOT(gotoOffset( uint, uint, bool, bool )) );
   }
   mGotoDialog->show();
 }
@@ -1468,8 +1468,8 @@ void CHexEditorWidget::find( void )
     mFindDialog = new CFindDialog( topLevelWidget(), 0, false );
     if( mFindDialog == 0 ) { return; }
     connect( mFindDialog,
-	     TQT_SIGNAL(findData(SSearchControl &, uint, bool)),
-	     TQT_SLOT(findData(SSearchControl &, uint, bool)) );
+	     TQ_SIGNAL(findData(SSearchControl &, uint, bool)),
+	     TQ_SLOT(findData(SSearchControl &, uint, bool)) );
   }
   mFindDialog->show();
 }
@@ -1616,10 +1616,10 @@ void CHexEditorWidget::findNavigator( SSearchControl &sc )
     mFindNavigatorDialog = new CFindNavigatorDialog(topLevelWidget(),0,false);
     if( mFindNavigatorDialog == 0 ) { return; }
     connect( mFindNavigatorDialog,
-	     TQT_SIGNAL(findData(SSearchControl &, uint, bool)),
-	     TQT_SLOT(findData(SSearchControl &, uint, bool)) );
-    connect( mFindNavigatorDialog, TQT_SIGNAL(makeKey(void)),
-	     TQT_SLOT(find()) );
+	     TQ_SIGNAL(findData(SSearchControl &, uint, bool)),
+	     TQ_SLOT(findData(SSearchControl &, uint, bool)) );
+    connect( mFindNavigatorDialog, TQ_SIGNAL(makeKey(void)),
+	     TQ_SLOT(find()) );
   }
   if( mFindNavigatorDialog->isVisible() == false )
   {
@@ -1639,8 +1639,8 @@ void CHexEditorWidget::replace( void )
     mReplaceDialog = new CReplaceDialog( topLevelWidget(), 0, false );
     if( mReplaceDialog == 0 ) { return; }
     connect( mReplaceDialog,
-	     TQT_SIGNAL( replaceData( SSearchControl &, uint)),
-	     TQT_SLOT( replaceData( SSearchControl &, uint)));
+	     TQ_SIGNAL( replaceData( SSearchControl &, uint)),
+	     TQ_SLOT( replaceData( SSearchControl &, uint)));
   }
   mReplaceDialog->show();
 }
@@ -1729,8 +1729,8 @@ void CHexEditorWidget::replacePrompt( SSearchControl &sc )
     mReplacePromptDialog = new CReplacePromptDialog(topLevelWidget(), 0,false);
     if( mReplacePromptDialog == 0 ) { return; }
     connect( mReplacePromptDialog,
-	     TQT_SIGNAL( replaceData( SSearchControl &, uint)),
-	     TQT_SLOT( replaceData( SSearchControl &, uint)));
+	     TQ_SIGNAL( replaceData( SSearchControl &, uint)),
+	     TQ_SLOT( replaceData( SSearchControl &, uint)));
   }
   if( mReplacePromptDialog->isVisible() == false )
   {
@@ -1783,8 +1783,8 @@ void CHexEditorWidget::insertPattern( void )
   {
     mInsertDialog = new CInsertDialog( topLevelWidget(), 0, false );
     if( mInsertDialog == 0 ) { return; }
-    connect( mInsertDialog, TQT_SIGNAL(execute( SInsertData & )),
-	     mHexView, TQT_SLOT(insert( SInsertData & )) );
+    connect( mInsertDialog, TQ_SIGNAL(execute( SInsertData & )),
+	     mHexView, TQ_SLOT(insert( SInsertData & )) );
   }
   mInsertDialog->show();
 }
@@ -1805,13 +1805,13 @@ void CHexEditorWidget::strings( void )
   {
     mStringDialog = new CStringDialog( topLevelWidget(), 0, false );
     if( mStringDialog == 0 ) { return; }
-    connect( mStringDialog, TQT_SIGNAL(markText( uint, uint, bool )),
-	     mHexView, TQT_SLOT(setMark( uint, uint, bool )) );
-    connect( mStringDialog, TQT_SIGNAL(collect()), TQT_SLOT(collectStrings()) );
-    connect( mHexView, TQT_SIGNAL(fileName( const TQString &, bool ) ),
-	     mStringDialog, TQT_SLOT( removeList() ) );
-    connect( mHexView, TQT_SIGNAL(dataChanged()),
-	     mStringDialog, TQT_SLOT(setDirty()) );
+    connect( mStringDialog, TQ_SIGNAL(markText( uint, uint, bool )),
+	     mHexView, TQ_SLOT(setMark( uint, uint, bool )) );
+    connect( mStringDialog, TQ_SIGNAL(collect()), TQ_SLOT(collectStrings()) );
+    connect( mHexView, TQ_SIGNAL(fileName( const TQString &, bool ) ),
+	     mStringDialog, TQ_SLOT( removeList() ) );
+    connect( mHexView, TQ_SIGNAL(dataChanged()),
+	     mStringDialog, TQ_SLOT(setDirty()) );
   }
   mStringDialog->show();
 }
@@ -1851,8 +1851,8 @@ void CHexEditorWidget::filter( void )
   {
     mFilterDialog = new CFilterDialog( topLevelWidget(), 0, false );
     if( mFilterDialog == 0 ) { return; }
-    connect( mFilterDialog, TQT_SIGNAL(filterData( SFilterControl & )),
-	     mHexView, TQT_SLOT(filter( SFilterControl & )) );
+    connect( mFilterDialog, TQ_SIGNAL(filterData( SFilterControl & )),
+	     mHexView, TQ_SLOT(filter( SFilterControl & )) );
   }
   mFilterDialog->show();
 }
@@ -1864,8 +1864,8 @@ void CHexEditorWidget::chart( void )
   {
     mCharTableDialog = new CCharTableDialog( topLevelWidget(), 0, false );
     if( mCharTableDialog == 0 ) { return; }
-    connect( mCharTableDialog, TQT_SIGNAL(assign( const TQByteArray & )),
-	     mHexView, TQT_SLOT(insert( const TQByteArray & )) );
+    connect( mCharTableDialog, TQ_SIGNAL(assign( const TQByteArray & )),
+	     mHexView, TQ_SLOT(insert( const TQByteArray & )) );
   }
   mCharTableDialog->show();
 }
@@ -1876,8 +1876,8 @@ void CHexEditorWidget::converter( void )
   if( mConverterDialog == 0 )
   {
     mConverterDialog = new CConverterDialog( this, "converter", false );
-    connect( mConverterDialog, TQT_SIGNAL(probeCursorValue(TQByteArray &, uint)),
-	     mHexView, TQT_SLOT(valueOnCursor(TQByteArray &, uint)) );
+    connect( mConverterDialog, TQ_SIGNAL(probeCursorValue(TQByteArray &, uint)),
+	     mHexView, TQ_SLOT(valueOnCursor(TQByteArray &, uint)) );
   }
   mConverterDialog->show();
 }
@@ -1889,10 +1889,10 @@ void CHexEditorWidget::statistics( void )
   {
     mFileInfoDialog = new CFileInfoDialog( topLevelWidget(), 0, false );
     if( mFileInfoDialog == 0 ) { return; }
-    connect( mFileInfoDialog, TQT_SIGNAL(collectStatistic(SStatisticControl &)),
-	     TQT_SLOT(collectStatistics(SStatisticControl &)));
-    connect( mHexView, TQT_SIGNAL(dataChanged()),
-	     mFileInfoDialog, TQT_SLOT(setDirty()) );
+    connect( mFileInfoDialog, TQ_SIGNAL(collectStatistic(SStatisticControl &)),
+	     TQ_SLOT(collectStatistics(SStatisticControl &)));
+    connect( mHexView, TQ_SIGNAL(dataChanged()),
+	     mFileInfoDialog, TQ_SLOT(setDirty()) );
   }
   mFileInfoDialog->show();
 }
@@ -1930,20 +1930,20 @@ void CHexEditorWidget::options( void )
     mOptionDialog = new COptionDialog( topLevelWidget(), 0, false );
     if( mOptionDialog == 0 ) { return; }
 
-    connect( mOptionDialog, TQT_SIGNAL(lineSizeChoice(const SDisplayLine &)),
-	     TQT_SLOT(setLineSize(const SDisplayLine &)) );
-    connect( mOptionDialog, TQT_SIGNAL(layoutChoice(const SDisplayLayout &)),
-	     TQT_SLOT(setLayout(const SDisplayLayout &)) );
-    connect( mOptionDialog, TQT_SIGNAL(fontChoice(const SDisplayFont &)),
-	     TQT_SLOT(setFont(const SDisplayFont &)) );
-    connect( mOptionDialog, TQT_SIGNAL(colorChoice(const SDisplayColor &)),
-	     TQT_SLOT(setColor(const SDisplayColor &)) );
-    connect( mOptionDialog, TQT_SIGNAL(cursorChoice(const SDisplayCursor &)),
-	     TQT_SLOT(setCursor(const SDisplayCursor &)) );
-    connect( mOptionDialog, TQT_SIGNAL(miscChoice(const SDisplayMisc &)),
-	     TQT_SLOT(setMisc(const SDisplayMisc &)) );
-    connect( mOptionDialog, TQT_SIGNAL(removeRecentFiles()),
-	     TQT_SIGNAL(removeRecentFiles()) );
+    connect( mOptionDialog, TQ_SIGNAL(lineSizeChoice(const SDisplayLine &)),
+	     TQ_SLOT(setLineSize(const SDisplayLine &)) );
+    connect( mOptionDialog, TQ_SIGNAL(layoutChoice(const SDisplayLayout &)),
+	     TQ_SLOT(setLayout(const SDisplayLayout &)) );
+    connect( mOptionDialog, TQ_SIGNAL(fontChoice(const SDisplayFont &)),
+	     TQ_SLOT(setFont(const SDisplayFont &)) );
+    connect( mOptionDialog, TQ_SIGNAL(colorChoice(const SDisplayColor &)),
+	     TQ_SLOT(setColor(const SDisplayColor &)) );
+    connect( mOptionDialog, TQ_SIGNAL(cursorChoice(const SDisplayCursor &)),
+	     TQ_SLOT(setCursor(const SDisplayCursor &)) );
+    connect( mOptionDialog, TQ_SIGNAL(miscChoice(const SDisplayMisc &)),
+	     TQ_SLOT(setMisc(const SDisplayMisc &)) );
+    connect( mOptionDialog, TQ_SIGNAL(removeRecentFiles()),
+	     TQ_SIGNAL(removeRecentFiles()) );
   }
   if( mOptionDialog->isVisible() == false )
   {
