@@ -93,7 +93,7 @@ KJotsMain::KJotsMain(const char* name)
     me_text->setFocusPolicy(TQWidget::StrongFocus);
     me_text->setEnabled(false);
     textStack->addWidget(me_text);
-    connect(me_text, TQT_SIGNAL(findSuccessful()), this, TQT_SLOT(slotFindSuccessful()));
+    connect(me_text, TQ_SIGNAL(findSuccessful()), this, TQ_SLOT(slotFindSuccessful()));
 
     roTextView = new KTextBrowser(textStack, "roTextView", true);
     textStack->addWidget(roTextView);
@@ -104,73 +104,73 @@ KJotsMain::KJotsMain(const char* name)
     splitter->setSizePolicy(TQSizePolicy(TQSizePolicy::Expanding, TQSizePolicy::Expanding, 2, 1));
 
     // create actions
-    actions[ACTION_NEXT_BOOK] = new TDEAction(i18n("Next Book"), TQString(), CTRL + Key_D, TQT_TQOBJECT(this),
-            TQT_SLOT(nextBook()), actionCollection(), "go_next_book");
-    actions[ACTION_PREV_BOOK] = new TDEAction(i18n("Previous Book"), TQString(), CTRL + SHIFT + Key_D, TQT_TQOBJECT(this),
-            TQT_SLOT(prevBook()), actionCollection(), "go_prev_book");
-    actions[ACTION_NEXT_PAGE] = new TDEAction(i18n("Next Page"), TQString(), CTRL + Key_PageDown, TQT_TQOBJECT(this),
-            TQT_SLOT(nextPage()), actionCollection(), "go_next_page");
-    actions[ACTION_PREV_PAGE] = new TDEAction(i18n("Previous Page"), TQString(), CTRL + Key_PageUp, TQT_TQOBJECT(this),
-            TQT_SLOT(prevPage()), actionCollection(), "go_prev_page");
+    actions[ACTION_NEXT_BOOK] = new TDEAction(i18n("Next Book"), TQString(), CTRL + Key_D, this,
+            TQ_SLOT(nextBook()), actionCollection(), "go_next_book");
+    actions[ACTION_PREV_BOOK] = new TDEAction(i18n("Previous Book"), TQString(), CTRL + SHIFT + Key_D, this,
+            TQ_SLOT(prevBook()), actionCollection(), "go_prev_book");
+    actions[ACTION_NEXT_PAGE] = new TDEAction(i18n("Next Page"), TQString(), CTRL + Key_PageDown, this,
+            TQ_SLOT(nextPage()), actionCollection(), "go_next_page");
+    actions[ACTION_PREV_PAGE] = new TDEAction(i18n("Previous Page"), TQString(), CTRL + Key_PageUp, this,
+            TQ_SLOT(prevPage()), actionCollection(), "go_prev_page");
 
-    actions[ACTION_NEW_PAGE] = KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(newEntry()), actionCollection());
+    actions[ACTION_NEW_PAGE] = KStdAction::openNew(this, TQ_SLOT(newEntry()), actionCollection());
     actions[ACTION_NEW_PAGE]->setText(i18n("&New Page"));
-    actions[ACTION_NEW_BOOK] = new TDEAction(i18n("New &Book..."), "contents", CTRL + SHIFT + Key_N, TQT_TQOBJECT(this),
-            TQT_SLOT(createNewBook()), actionCollection(), "new_book");
+    actions[ACTION_NEW_BOOK] = new TDEAction(i18n("New &Book..."), "contents", CTRL + SHIFT + Key_N, this,
+            TQ_SLOT(createNewBook()), actionCollection(), "new_book");
 
     exportPageMenu = new TDEActionMenu(i18n("Export Page"), actionCollection(), "save_page_to");
-    actions[ACTION_PAGE2TEXT] = new TDEAction(i18n("To Text File..."), TQString(), 0, TQT_TQOBJECT(this),
-            TQT_SLOT(writePage()), actionCollection(), "save_page_to_ascii");
+    actions[ACTION_PAGE2TEXT] = new TDEAction(i18n("To Text File..."), TQString(), 0, this,
+            TQ_SLOT(writePage()), actionCollection(), "save_page_to_ascii");
     actions[ACTION_PAGE2TEXT]->plug(exportPageMenu->popupMenu());
-    actions[ACTION_PAGE2HTML] = new TDEAction(i18n("To HTML File..."), TQString(), 0, TQT_TQOBJECT(this),
-            TQT_SLOT(writePageToHTML()), actionCollection(), "save_page_to_html");
+    actions[ACTION_PAGE2HTML] = new TDEAction(i18n("To HTML File..."), TQString(), 0, this,
+            TQ_SLOT(writePageToHTML()), actionCollection(), "save_page_to_html");
     actions[ACTION_PAGE2HTML]->plug(exportPageMenu->popupMenu());
 
     exportBookMenu = new TDEActionMenu(i18n("Export Book"), actionCollection(), "save_book_to");
-    actions[ACTION_BOOK2TEXT] = new TDEAction(i18n("To Text File..."), TQString(), 0, TQT_TQOBJECT(this),
-            TQT_SLOT(writeBook()), actionCollection(), "save_book_to_ascii");
+    actions[ACTION_BOOK2TEXT] = new TDEAction(i18n("To Text File..."), TQString(), 0, this,
+            TQ_SLOT(writeBook()), actionCollection(), "save_book_to_ascii");
     actions[ACTION_BOOK2TEXT]->plug(exportBookMenu->popupMenu());
-    actions[ACTION_BOOK2HTML] = new TDEAction(i18n("To HTML File..."), TQString(), 0, TQT_TQOBJECT(this),
-            TQT_SLOT(writeBookToHTML()), actionCollection(), "save_book_to_html");
+    actions[ACTION_BOOK2HTML] = new TDEAction(i18n("To HTML File..."), TQString(), 0, this,
+            TQ_SLOT(writeBookToHTML()), actionCollection(), "save_book_to_html");
     actions[ACTION_BOOK2HTML]->plug(exportBookMenu->popupMenu());
 
-    actions[ACTION_DELETE_PAGE] = new TDEAction(i18n("&Delete Page"), "edit-delete", CTRL + Key_Delete, TQT_TQOBJECT(this),
-            TQT_SLOT(deleteEntry()), actionCollection(), "del_page");
-    actions[ACTION_DELETE_BOOK] = new TDEAction(i18n("Delete Boo&k"), "edit-delete", CTRL + SHIFT + Key_Delete, TQT_TQOBJECT(this),
-            TQT_SLOT(deleteBook()), actionCollection(), "del_folder");
+    actions[ACTION_DELETE_PAGE] = new TDEAction(i18n("&Delete Page"), "edit-delete", CTRL + Key_Delete, this,
+            TQ_SLOT(deleteEntry()), actionCollection(), "del_page");
+    actions[ACTION_DELETE_BOOK] = new TDEAction(i18n("Delete Boo&k"), "edit-delete", CTRL + SHIFT + Key_Delete, this,
+            TQ_SLOT(deleteBook()), actionCollection(), "del_folder");
 
     actions[ACTION_MANUAL_SAVE] = new TDEAction(i18n("Manual Save"), 0, TDEStdAccel::save(),
-                         TQT_TQOBJECT(this), TQT_SLOT(autoSave()), actionCollection(), "manual_save");
-    actions[ACTION_PRINT] = KStdAction::print(TQT_TQOBJECT(this), TQT_SLOT(slotPrint()), actionCollection());
-    actions[ACTION_QUIT] = KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(slotQuit()), actionCollection());
+                         this, TQ_SLOT(autoSave()), actionCollection(), "manual_save");
+    actions[ACTION_PRINT] = KStdAction::print(this, TQ_SLOT(slotPrint()), actionCollection());
+    actions[ACTION_QUIT] = KStdAction::quit(this, TQ_SLOT(slotQuit()), actionCollection());
 
-    actions[ACTION_CUT] = KStdAction::cut(TQT_TQOBJECT(me_text), TQT_SLOT(cut()), actionCollection());
-    connect(me_text, TQT_SIGNAL(copyAvailable(bool)), actions[ACTION_CUT], TQT_SLOT(setEnabled(bool)));
+    actions[ACTION_CUT] = KStdAction::cut(me_text, TQ_SLOT(cut()), actionCollection());
+    connect(me_text, TQ_SIGNAL(copyAvailable(bool)), actions[ACTION_CUT], TQ_SLOT(setEnabled(bool)));
     actions[ACTION_CUT]->setEnabled(false);
-    actions[ACTION_COPY]  = KStdAction::copy(TQT_TQOBJECT(me_text), TQT_SLOT(copy()), actionCollection());
-    connect(me_text, TQT_SIGNAL(copyAvailable(bool)), actions[ACTION_COPY], TQT_SLOT(setEnabled(bool)));
+    actions[ACTION_COPY]  = KStdAction::copy(me_text, TQ_SLOT(copy()), actionCollection());
+    connect(me_text, TQ_SIGNAL(copyAvailable(bool)), actions[ACTION_COPY], TQ_SLOT(setEnabled(bool)));
     actions[ACTION_COPY]->setEnabled(false);
-    actions[ACTION_PASTE2TITLE] = new TDEAction(i18n("Copy &into Page Title"), "edit-copy", CTRL+Key_T, TQT_TQOBJECT(this),
-            TQT_SLOT(copySelection()), actionCollection(), "copyIntoTitle");
-    connect(me_text, TQT_SIGNAL(copyAvailable(bool)), actions[ACTION_PASTE2TITLE], TQT_SLOT(setEnabled(bool)));
+    actions[ACTION_PASTE2TITLE] = new TDEAction(i18n("Copy &into Page Title"), "edit-copy", CTRL+Key_T, this,
+            TQ_SLOT(copySelection()), actionCollection(), "copyIntoTitle");
+    connect(me_text, TQ_SIGNAL(copyAvailable(bool)), actions[ACTION_PASTE2TITLE], TQ_SLOT(setEnabled(bool)));
     actions[ACTION_PASTE2TITLE]->setEnabled(false);
-    actions[ACTION_PASTE]  = KStdAction::pasteText(TQT_TQOBJECT(me_text), TQT_SLOT(paste()), actionCollection());
+    actions[ACTION_PASTE]  = KStdAction::pasteText(me_text, TQ_SLOT(paste()), actionCollection());
 
-    actions[ACTION_FIND] = KStdAction::find( TQT_TQOBJECT(this), TQT_SLOT( slotSearch() ), actionCollection() );
-    actions[ACTION_FIND_NEXT] = KStdAction::findNext( TQT_TQOBJECT(this), TQT_SLOT( slotRepeatSearch() ), actionCollection() );
+    actions[ACTION_FIND] = KStdAction::find( this, TQ_SLOT( slotSearch() ), actionCollection() );
+    actions[ACTION_FIND_NEXT] = KStdAction::findNext( this, TQ_SLOT( slotRepeatSearch() ), actionCollection() );
     actions[ACTION_FIND_NEXT]->setEnabled(false);
-    actions[ACTION_REPLACE] = KStdAction::replace( TQT_TQOBJECT(this), TQT_SLOT( slotReplace() ), actionCollection() );
+    actions[ACTION_REPLACE] = KStdAction::replace( this, TQ_SLOT( slotReplace() ), actionCollection() );
 
-    actions[ACTION_RENAME] = new TDEAction(i18n("Rename..."), TQString(), CTRL + Key_M, TQT_TQOBJECT(this),
-            TQT_SLOT(slotRenameEntry()), actionCollection(), "rename_entry");
-    actions[ACTION_INSERT_DATE] = new TDEAction(i18n("Insert Date"), "date", CTRL + Key_I, TQT_TQOBJECT(this),
-            TQT_SLOT(insertDate()), actionCollection(), "insert_date");
+    actions[ACTION_RENAME] = new TDEAction(i18n("Rename..."), TQString(), CTRL + Key_M, this,
+            TQ_SLOT(slotRenameEntry()), actionCollection(), "rename_entry");
+    actions[ACTION_INSERT_DATE] = new TDEAction(i18n("Insert Date"), "date", CTRL + Key_I, this,
+            TQ_SLOT(insertDate()), actionCollection(), "insert_date");
 
-    KStdAction::preferences(TQT_TQOBJECT(this), TQT_SLOT(configure()), actionCollection());
+    KStdAction::preferences(this, TQ_SLOT(configure()), actionCollection());
 
     bookmarkMenu = new TDEActionMenu(i18n("&Bookmarks"), "bookmarks", actionCollection(), "bookmarks");
     KJotsBookmarks* bookmarks = new KJotsBookmarks(this);
-    connect(bookmarks, TQT_SIGNAL(openPage(const TQString&)), TQT_SLOT(jumpToBookmark(const TQString&)));
+    connect(bookmarks, TQ_SIGNAL(openPage(const TQString&)), TQ_SLOT(jumpToBookmark(const TQString&)));
     new KBookmarkMenu(KBookmarkManager::managerForFile(locateLocal("appdata","bookmarks.xml")),
                       bookmarks, bookmarkMenu->popupMenu(),
                       actionCollection(), true);
@@ -204,25 +204,25 @@ KJotsMain::KJotsMain(const char* name)
     updateConfiguration();
     updateMenu();
 
-    TQTimer::singleShot(0, this, TQT_SLOT(slotSetupInterface()));
+    TQTimer::singleShot(0, this, TQ_SLOT(slotSetupInterface()));
 
     //connect new slots
-    connect(subjectList, TQT_SIGNAL(selectionChanged(TQListViewItem*)),
-            this, TQT_SLOT(jumpToEntry(TQListViewItem*)));
-    connect(subjectList, TQT_SIGNAL(moved(TQListViewItem*, TQListViewItem*, TQListViewItem*)),
-            this, TQT_SLOT(slotItemMoved(TQListViewItem*, TQListViewItem*, TQListViewItem*)));
-    connect(subjectList, TQT_SIGNAL(expanded(TQListViewItem*)),
-            this, TQT_SLOT(slotExpandBook(TQListViewItem*)));
-    connect(subjectList, TQT_SIGNAL(collapsed(TQListViewItem*)),
-            this, TQT_SLOT(slotCollapseBook(TQListViewItem*)));
-    connect(subjectList, TQT_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)),
-            this, TQT_SLOT(showListviewContextMenu(TDEListView*,TQListViewItem*,const TQPoint&)));
-    connect(subjectList, TQT_SIGNAL(itemRenamed(TQListViewItem*,const TQString&,int)),
-            this, TQT_SLOT(slotItemRenamed(TQListViewItem*,const TQString&,int)));
-    connect(roTextView, TQT_SIGNAL(urlClick(const TQString&)),
-            this, TQT_SLOT(linkClicked(const TQString&)));
-    connect(m_autosaveTimer, TQT_SIGNAL(timeout()),
-            this, TQT_SLOT(autoSave()));
+    connect(subjectList, TQ_SIGNAL(selectionChanged(TQListViewItem*)),
+            this, TQ_SLOT(jumpToEntry(TQListViewItem*)));
+    connect(subjectList, TQ_SIGNAL(moved(TQListViewItem*, TQListViewItem*, TQListViewItem*)),
+            this, TQ_SLOT(slotItemMoved(TQListViewItem*, TQListViewItem*, TQListViewItem*)));
+    connect(subjectList, TQ_SIGNAL(expanded(TQListViewItem*)),
+            this, TQ_SLOT(slotExpandBook(TQListViewItem*)));
+    connect(subjectList, TQ_SIGNAL(collapsed(TQListViewItem*)),
+            this, TQ_SLOT(slotCollapseBook(TQListViewItem*)));
+    connect(subjectList, TQ_SIGNAL(contextMenu(TDEListView*,TQListViewItem*,const TQPoint&)),
+            this, TQ_SLOT(showListviewContextMenu(TDEListView*,TQListViewItem*,const TQPoint&)));
+    connect(subjectList, TQ_SIGNAL(itemRenamed(TQListViewItem*,const TQString&,int)),
+            this, TQ_SLOT(slotItemRenamed(TQListViewItem*,const TQString&,int)));
+    connect(roTextView, TQ_SIGNAL(urlClick(const TQString&)),
+            this, TQ_SLOT(linkClicked(const TQString&)));
+    connect(m_autosaveTimer, TQ_SIGNAL(timeout()),
+            this, TQ_SLOT(autoSave()));
 }
 
 void KJotsMain::slotSetupInterface()
@@ -399,7 +399,7 @@ void KJotsMain::configure()
     confPageMisc* cpMisc = new confPageMisc(0, "Autosave");
     dialog->addPage(cpMisc, i18n("Autosave"), "misc");
 
-    connect(dialog, TQT_SIGNAL(settingsChanged()), this, TQT_SLOT(updateConfiguration()));
+    connect(dialog, TQ_SIGNAL(settingsChanged()), this, TQ_SLOT(updateConfiguration()));
 
     dialog->show();
 }
@@ -657,7 +657,7 @@ void KJotsMain::slotFindSuccessful()
 void KJotsMain::showListviewContextMenu(TDEListView*, TQListViewItem* i, const TQPoint& p)
 {
     if ( invalidMoveFlag ) return; //Prevent race condition
-    TDEActionMenu* am = new TDEActionMenu(TQT_TQOBJECT(this));
+    TDEActionMenu* am = new TDEActionMenu(this);
 
     if (!i)
     {
