@@ -64,7 +64,7 @@ namespace KSim
       void makeDirs();
 
       TQSize sizeHint(KPanelExtension::Position, TQSize maxSize) const;
-      void positionChange(Qt::Orientation);
+      void positionChange(TQt::Orientation);
 
     k_dcop:
       const TQString &hostname() const;
