@@ -25,7 +25,7 @@
 
 class EditAction : public EditActionBase
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	IRAIt theAction;
 	TQMap<TQString, TQString> applicationMap, functionMap;
